import '../style/index.less'

var loadingStatus = {}
loadingStatus.config = {
    loadingMsg: '正在加载',
    successMsg: '加载成功',
    emptyMsg: '暂无数据',
    errorMsg: '加载失败'
}

loadingStatus.install = (Vue, options) => {
    var loadStatusComponent = Vue.extend({
        template: `<div @click="$emit('feedback', fnDispose.feedback)" :style="{'height': fnHeight}" :class="[fnDispose.class, fnGlobal]" class="loading-status">
                        <div class="loading-content">
                            <i v-if="status[2] !== false" class="loading-icon"></i><span v-if="fnDispose.msg" class="loading-msg">{{ fnDispose.msg }}</span>
                        </div>
                    </div>`,
        props: {
            status: {
                type: Array,
                default () {
                    return [true, loadingStatus.config.loadingMsg]
                }
            },
            global: {
                type: Boolean,
                default: null
            },
            height: {
                type: [String, Number],
                default: 100
            }
        },
        computed: {
            fnDispose () {
                if (this.status && this.status.length) {
                    let status = this.status[0]
                    if (status === 1) {
                        // 加载成功
                        return {
                            class: 'success',
                            msg: this.status[1] === undefined ? loadingStatus.config.successMsg : this.status[1],
                            feedback: 1
                        }
                    }
                    else if (status === 0) {
                        // 暂无数据
                        return {
                            class: 'empty',
                            msg: this.status[1] === undefined ? loadingStatus.config.emptyMsg : this.status[1],
                            feedback: 0
                        }
                    }
                    else if (status === -1) {
                        // 加载失败
                        return {
                            class: 'error',
                            msg: this.status[1] === undefined ? loadingStatus.config.errorMsg : this.status[1],
                            feedback: -1
                        }
                    }
                    else {
                        // 正在加载
                        return {
                            class: 'loading',
                            msg: this.status[1] === undefined ? loadingStatus.config.loadingMsg : this.status[1],
                            feedback: true
                        }
                    }
                }
                else {
                    // 正在加载
                    return {
                        class: 'success',
                        text: this.status[1] === undefined ? loadingStatus.config.successMsg : this.status[1],
                        feedback: 1
                    }
                }
            },
            fnHeight () {
                if (this.global) {
                    return
                }
                if (this.height > 0) {
                    return this.height + 'px'
                }
                else {
                    return this.height
                }
            },
            fnGlobal () {
                if (this.global === true) {
                    return 'fixed'
                }
                else if (this.global === false) {
                    return 'absolute'
                }
                else {
                    return
                }
            }
        }
    })
    Vue.component('loading-status', loadStatusComponent)
}

if (window.Vue) {
    Vue.use(loadingStatus)
}

export default loadingStatus